Txms class

Implemented types

Constructors

Txms()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

count(String hex, [String? type]) int
Counts the number of segments needed to transmit a hex message.
override
decode(String data) String
Decodes a previously encoded message back to its original hex format.
override
downloadMessage(dynamic hex, {String? optionalFilename, String? optionalPath}) Future<String>
Downloads a message to a file.
override
encode(String hex) String
Encodes a hex string into a format suitable for SMS/MMS transmission.
override
generateMessageUri(String type, {dynamic number, String? message, dynamic network, bool encodeMessage = true, String platform = 'global'}) String
Generates a message URI for either SMS or MMS.
override
getEndpoint([dynamic network, dynamic countriesList]) Map<String, List<String>>
Gets the endpoint information for a specific network and countries.
override
getNumber({String? iso3166A2, bool returnNone = false, dynamic network}) String?
Selects a number for a country, with calling-code, EFTA/EEA/EU, WB6/EU, and other organization fallbacks matching txms.js.
override
mms({dynamic number, String? message, dynamic network, bool encodeMessage = true, String platform = 'global'}) String
Generates an MMS URI with the encoded message.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openMmsClient({dynamic number, String? message, dynamic network, bool encodeMessage = true, String platform = 'global'}) Future<bool>
Opens the device's MMS client with the encoded message Returns true if the MMS client was opened successfully
override
openSmsClient({dynamic number, String? message, dynamic network, bool encodeMessage = true, String platform = 'global'}) Future<bool>
Opens the device's SMS client with the encoded message Returns true if the SMS client was opened successfully
override
parseSMS(String number, String text) SmsParseResult?
Parses a transaction-status SMS received from a configured TxMS number.
override
sms({dynamic number, String? message, dynamic network, bool encodeMessage = true, String platform = 'global'}) String
Generates an SMS URI with the encoded message.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

addAlias(String name, dynamic network) → void
addCountry(dynamic networkId, String countryCode, List<String> phoneNumbers) → void
resetCustomPhoneNumbers() → void
setCustomPhoneNumbers(dynamic networkId, String countryCode, List<String> phoneNumbers) → void